==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/MAPACETATE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ACETATETYPE" type="{http://schemas.datastream.net/MP_fields}ACETATETYPE_Type"/>
 *         &lt;element name="FROMCOORDINATE" type="{http://schemas.datastream.net/MP_fields}MAPCOORDINATE_Type"/>
 *         &lt;element name="TOCOORDINATE" type="{http://schemas.datastream.net/MP_fields}MAPCOORDINATE_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "acetatetype",
    "fromcoordinate",
    "tocoordinate"
})
@XmlRootElement(name = "MAPACETATE")
public class MAPACETATE {

    @XmlElement(name = "ACETATETYPE", required = true)
    @XmlSchemaType(name = "string")
    protected ACETATETYPE_Type acetatetype;
    @XmlElement(name = "FROMCOORDINATE", required = true)
    protected MAPCOORDINATE_Type fromcoordinate;
    @XmlElement(name = "TOCOORDINATE")
    protected MAPCOORDINATE_Type tocoordinate;

    /**
     * Obtient la valeur de la propriété acetatetype.
     * 
     * @return
     *     possible object is
     *     {@link ACETATETYPE_Type }
     *     
     */
    public ACETATETYPE_Type getACETATETYPE() {
        return acetatetype;
    }

    /**
     * Définit la valeur de la propriété acetatetype.
     * 
     * @param value
     *     allowed object is
     *     {@link ACETATETYPE_Type }
     *     
     */
    public void setACETATETYPE(ACETATETYPE_Type value) {
        this.acetatetype = value;
    }

    /**
     * Obtient la valeur de la propriété fromcoordinate.
     * 
     * @return
     *     possible object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public MAPCOORDINATE_Type getFROMCOORDINATE() {
        return fromcoordinate;
    }

    /**
     * Définit la valeur de la propriété fromcoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public void setFROMCOORDINATE(MAPCOORDINATE_Type value) {
        this.fromcoordinate = value;
    }

    /**
     * Obtient la valeur de la propriété tocoordinate.
     * 
     * @return
     *     possible object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public MAPCOORDINATE_Type getTOCOORDINATE() {
        return tocoordinate;
    }

    /**
     * Définit la valeur de la propriété tocoordinate.
     * 
     * @param value
     *     allowed object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public void setTOCOORDINATE(MAPCOORDINATE_Type value) {
        this.tocoordinate = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/MAPACETATE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ACETATETYPE" type="{http://schemas.datastream.net/MP_fields}ACETATETYPE_Type"/>
 *         &lt;element name="FROMCOORDINATE" type="{http://schemas.datastream.net/MP_fields}MAPCOORDINATE_Type"/>
 *         &lt;element name="TOCOORDINATE" type="{http://schemas.datastream.net/MP_fields}MAPCOORDINATE_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "acetatetype",
    "fromcoordinate",
    "tocoordinate"
})
@XmlRootElement(name = "MAPACETATE")
public class MAPACETATE {

    @XmlElement(name = "ACETATETYPE", required = true)
    @XmlSchemaType(name = "string")
    protected ACETATETYPE_Type acetatetype;
    @XmlElement(name = "FROMCOORDINATE", required = true)
    protected MAPCOORDINATE_Type fromcoordinate;
    @XmlElement(name = "TOCOORDINATE")
    protected MAPCOORDINATE_Type tocoordinate;

    /**
     * Gets the value of the acetatetype property.
     * 
     * @return
     *     possible object is
     *     {@link ACETATETYPE_Type }
     *     
     */
    public ACETATETYPE_Type getACETATETYPE() {
        return acetatetype;
    }

    /**
     * Sets the value of the acetatetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACETATETYPE_Type }
     *     
     */
    public void setACETATETYPE(ACETATETYPE_Type value) {
        this.acetatetype = value;
    }

    /**
     * Gets the value of the fromcoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public MAPCOORDINATE_Type getFROMCOORDINATE() {
        return fromcoordinate;
    }

    /**
     * Sets the value of the fromcoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public void setFROMCOORDINATE(MAPCOORDINATE_Type value) {
        this.fromcoordinate = value;
    }

    /**
     * Gets the value of the tocoordinate property.
     * 
     * @return
     *     possible object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public MAPCOORDINATE_Type getTOCOORDINATE() {
        return tocoordinate;
    }

    /**
     * Sets the value of the tocoordinate property.
     * 
     * @param value
     *     allowed object is
     *     {@link MAPCOORDINATE_Type }
     *     
     */
    public void setTOCOORDINATE(MAPCOORDINATE_Type value) {
        this.tocoordinate = value;
    }

}
